/*  mptables.h
 *
 *  This include file contains the executive's pre-initialized tables
 *  used in a multiprocessor configuration.
 *
 *  COPYRIGHT (c) 1989-1999.
 *  On-Line Applications Research Corporation (OAR).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id: mptables.h,v 1.9 2005/01/28 05:00:20 ralf Exp $
 */

#ifndef _RTEMS_MPTABLES_H
#define _RTEMS_MPTABLES_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
}
#endif

#endif
/* end of include file */
